import { Rect, Text } from '@antv/g';
import { GUI } from '../core/gui';
import type { Pair } from '../slider/types';
import type { StyleState, RectProps } from '../../types';
import type { LegendBaseCfg, LegendBaseOptions } from './types';
export declare abstract class LegendBase<T extends LegendBaseCfg> extends GUI<Required<T>> {
    static tag: string;
    protected backgroundShape: Rect;
    protected titleShape: Text;
    protected static defaultOptions: {
        style: {
            x: number;
            y: number;
            padding: number;
            orient: string;
            backgroundStyle: {
                default: {
                    fill: string;
                    lineWidth: number;
                };
            };
            title: {
                content: string;
                spacing: number;
                align: string;
                style: {
                    fill: string;
                    fontWeight: string;
                    fontSize: number;
                    textBaseline: string;
                };
                formatter: (text: string) => string;
            };
        };
        type: string;
    };
    constructor(options: LegendBaseOptions);
    init(): void;
    update(cfg?: Partial<LegendBaseCfg>): void;
    /**
     * 背景属性
     */
    protected abstract getBackgroundShapeCfg(): RectProps;
    protected getStyle(name: string | string[], state?: StyleState): Partial<unknown>;
    /**
     * 根据方向取值
     */
    protected getOrientVal<T>([x, y]: Pair<T>): T;
    protected getPadding(padding?: T["padding"]): [number, number, number, number];
    protected getAvailableSpace(): {
        x: number;
        y: any;
    };
    protected createBackground(): void;
    /**
     * 创建图例标题配置
     */
    protected getTitleShapeCfg(): {
        text: string;
        textAlign?: "left" | "start" | "center" | "end" | "right" | undefined;
        textBaseline?: "top" | "hanging" | "middle" | "alphabetic" | "ideographic" | "bottom" | undefined;
        fontStyle?: "normal" | "italic" | "oblique" | undefined;
        fontSize?: number | undefined;
        fontFamily?: string | undefined;
        fontWeight?: number | "bold" | "normal" | "bolder" | "lighter" | undefined;
        fontVariant?: string | undefined;
        lineHeight?: number | undefined;
        letterSpacing?: number | undefined;
        miterLimit?: number | undefined;
        padding?: number | undefined;
        whiteSpace?: "pre" | undefined;
        leading?: number | undefined;
        wordWrap?: boolean | undefined;
        wordWrapWidth?: number | undefined;
        dropShadow?: boolean | undefined;
        dropShadowDistance?: number | undefined;
        x?: number | undefined;
        y?: number | undefined;
        origin?: [number, number] | Float32Array | [number, number, number] | undefined;
        anchor?: [number, number] | Float32Array | [number, number, number] | undefined;
        visibility?: "visible" | "hidden" | undefined;
        zIndex?: number | undefined;
        cursor?: import("@antv/g").Cursor | undefined;
        clipPath?: import("@antv/g").DisplayObject<any> | null | undefined;
        clipPathTargets?: import("@antv/g").DisplayObject<any>[] | undefined;
        offsetPath?: import("@antv/g").DisplayObject<any> | null | undefined;
        offsetPathTargets?: import("@antv/g").DisplayObject<any>[] | undefined;
        stroke?: (string | null) | undefined;
        strokeOpacity?: number | undefined;
        fill?: (string | null) | undefined;
        fillOpacity?: number | undefined;
        opacity?: number | undefined;
        lineWidth?: number | undefined;
        lineAppendWidth?: number | undefined;
        lineCap?: "butt" | "round" | "square" | undefined;
        lineJoin?: "round" | "bevel" | "miter" | undefined;
        lineDash?: number[] | null | undefined;
    };
    /**
     * 创建图例标题
     */
    protected createTitle(): void;
    protected adjustTitle(): void;
}
