import { Group, Rect, Text } from '@antv/g';
import { LegendBase } from './base';
import type { ContinuousCfg, ContinuousOptions } from './types';
export type { ContinuousOptions };
export declare class Continuous extends LegendBase<ContinuousCfg> {
    static tag: string;
    /**
     * 结构：
     * this
     * |- titleShape
     * |-backgroundShape
     *   |- labelsShape
     *   |- railShape
     *      |- pathGroup
     *      |- backgroundGroup
     *      |- startHandle
     *      |- endHandle
     *      |- indicator
     */
    private labelsShape;
    private railShape;
    private startHandle;
    private endHandle;
    /**
     * 指示器
     */
    private indicatorShape;
    /**
     * 当前交互的对象
     */
    private target;
    /**
     * 上次鼠标事件的位置
     */
    private prevValue;
    protected static defaultOptions: any;
    constructor(options: ContinuousOptions);
    init(): void;
    update(cfg: Partial<ContinuousCfg>): void;
    clear(): void;
    /**
     * 设置指示器
     * @param value 设置的值，用于确定位置
     * @param text 可选；显示的文本，若无则通过value取值
     * @param useFormatter 是否使用formatter
     * @returns
     */
    setIndicator(value: false | number, text?: string, useFormatter?: boolean): void;
    getIndicator(subNode?: 'text' | 'background'): Text | Group | Rect;
    getSelection(): [number, number];
    /**
     * 设置选区
     * @param stVal 开始值
     * @param endVal 结束值
     * @param isOffset stVal和endVal是否为偏移量
     */
    setSelection(stVal: number, endVal: number, isOffset?: boolean): void;
    /**
     * 设置Handle的文本
     */
    setHandleText(text1?: string, text2?: string, useFormatter?: boolean): void;
    /**
     * 获取颜色
     */
    protected getColor(): string | string[];
    protected getBackgroundShapeCfg(): {
        width: number;
        height: number;
    };
    /**
     * 获得滑动步长
     * 未指定时默认为range的1%;
     */
    private getStep;
    /**
     * 取值附近的步长刻度上的值
     */
    private getStepValueByValue;
    /**
     * 取值所在的刻度范围
     */
    private getTickIntervalByValue;
    /**
     * 将选区调整至tick位置
     */
    private adjustSelection;
    /**
     * 获取某个值在orient方向上的偏移量
     * reverse: 屏幕偏移量 -> 值
     */
    private getValueOffset;
    private getSafetySelections;
    private getLabelsShapeCfg;
    private createLabels;
    private getRailShapeCfg;
    private createRail;
    /**
     * 获取手柄属性
     */
    private getHandleShapeCfg;
    /**
     *  创建手柄
     */
    private createHandle;
    private createHandles;
    /**
     * 更新handle
     */
    updateHandles(): void;
    /**
     * 获得手柄、手柄内icon和text的对象
     */
    private getHandle;
    /**
     * 获得指示器配置
     */
    private getIndicatorShapeCfg;
    private createIndicator;
    /**
     * 调整handle结构
     */
    private adjustHandle;
    /**
     * 调整labels结构
     */
    private adjustLabels;
    /**
     * 调整指示器结构
     */
    private adjustIndicator;
    /**
     * 对图例进行布局
     */
    private adjustLayout;
    /**
     * 事件触发的位置对应的value值
     * @param limit {boolean} 我也忘了要干啥了
     */
    private getEventPosValue;
    /**
     * 绑定事件
     */
    private bindEvents;
    /**
     * 开始拖拽
     */
    private onDragStart;
    /**
     * 拖拽
     */
    private onDragging;
    /**
     * 结束拖拽
     */
    private onDragEnd;
    private onHoverStart;
    private onHovering;
    /**
     * hover结束
     */
    private onHoverEnd;
    private dispatchIndicated;
}
