import type { DisplayObjectConfig, ShapeAttrs, StyleState, MixAttrs, TextProps, ImageProps, PathProps } from '../../types';
import type { MarkerCfg } from '../marker/types';
export declare type State = StyleState | 'default-active' | 'selected-active';
export declare type SymbolCfg = MarkerCfg['symbol'];
export declare type RailCfg = {
    width?: number;
    height?: number;
    type?: 'color' | 'size';
    chunked?: boolean;
    ticks?: number[];
    isGradient?: boolean | 'auto';
    backgroundColor?: string;
};
export declare type IndicatorCfg = {
    size?: number;
    backgroundStyle?: ShapeAttrs;
    spacing?: number;
    padding?: number | number[];
    text?: {
        formatter?: (value: number) => string;
        style?: TextProps;
    };
};
export declare type HandleCfg = {
    size?: number;
    spacing?: number;
    icon?: {
        marker?: SymbolCfg;
        style?: ImageProps | PathProps;
    };
    text?: {
        style?: TextProps;
        formatter?: (value: number) => string;
        align?: 'rail' | 'inside' | 'outside';
    };
};
declare type CategoryItem = {
    state?: State;
    name?: string;
    value?: string;
    id?: string;
};
export declare type ItemMarkerCfg = {
    marker?: SymbolCfg;
    size?: number;
    spacing?: number;
    style?: MixAttrs<ShapeAttrs>;
};
export declare type ItemNameCfg = {
    spacing?: number;
    style?: MixAttrs<Partial<TextProps>>;
    formatter?: (text: string) => string;
};
export declare type ItemValueCfg = {
    spacing?: number;
    align?: 'left' | 'right';
    style?: MixAttrs<Partial<TextProps>>;
    formatter?: (text: string) => string;
};
export declare type CategoryItemCfg = {
    identify?: string;
    itemWidth?: number;
    maxItemWidth?: number;
    state?: State;
    itemMarker: ItemMarkerCfg;
    itemName: {
        content?: string;
        spacing?: number;
        style?: MixAttrs<Partial<TextProps>>;
    };
    itemValue: {
        content?: string;
        spacing?: number;
        style: MixAttrs<Partial<TextProps>>;
    };
    backgroundStyle: MixAttrs<ShapeAttrs>;
};
declare type PageNavigatorCfg = {
    button: {
        marker: SymbolCfg | ((type: 'prev' | 'next') => SymbolCfg);
        style: MixAttrs<ShapeAttrs>;
        size: number;
    };
    pagination: {
        style: TextProps;
        divider: string;
        formatter: (pageNumber: number) => number | string;
    };
};
export declare type LegendBaseCfg = ShapeAttrs & {
    padding?: number | number[];
    backgroundStyle?: MixAttrs<ShapeAttrs>;
    orient?: 'horizontal' | 'vertical';
    title?: {
        content?: string;
        spacing?: number;
        align?: 'left' | 'center' | 'right';
        style?: Partial<TextProps>;
        formatter?: (text: string) => string;
    };
    type?: 'category' | 'continuous';
};
export declare type LegendBaseOptions = DisplayObjectConfig<LegendBaseCfg>;
export declare type ContinuousCfg = LegendBaseCfg & {
    min: number;
    max: number;
    start?: number;
    end?: number;
    color?: string | string[];
    label?: false | {
        style?: TextProps;
        spacing?: number;
        formatter?: (value: number, idx: number) => string;
        align?: 'rail' | 'inside' | 'outside';
    };
    rail?: RailCfg;
    slidable?: boolean;
    step?: number;
    handle?: false | HandleCfg;
    indicator?: false | IndicatorCfg;
};
export declare type ContinuousOptions = DisplayObjectConfig<ContinuousCfg>;
export declare type CategoryCfg = LegendBaseCfg & {
    items: CategoryItem[];
    maxWidth?: number;
    maxHeight?: number;
    maxCols?: number;
    maxRows?: number;
    itemWidth?: number;
    maxItemWidth?: number;
    spacing?: [number, number];
    itemMarker?: Partial<ItemMarkerCfg> | ((item: CategoryItem, index: number, items: CategoryItem[]) => ItemMarkerCfg);
    itemName?: ItemNameCfg | ((item: CategoryItem, index: number, items: CategoryItem[]) => ItemNameCfg);
    itemValue?: ItemValueCfg | ((item: CategoryItem, index: number, items: CategoryItem[]) => ItemValueCfg);
    itemBackgroundStyle?: MixAttrs<ShapeAttrs> | ((item: CategoryItem, index: number, items: CategoryItem[]) => MixAttrs<ShapeAttrs>);
    autoWrap?: boolean;
    reverse?: boolean;
    pageNavigator?: false | PageNavigatorCfg;
};
export declare type CategoryOptions = DisplayObjectConfig<CategoryCfg>;
export {};
