import { GUI } from '../core/gui';
import type { ScrollbarOptions, ScrollbarCfg } from './types';
export type { ScrollbarOptions, ScrollbarCfg };
export declare class Scrollbar extends GUI<Required<ScrollbarCfg>> {
    /**
     * tag
     */
    static tag: string;
    private trackShape;
    private thumbShape;
    /**
     * 拖动开始位置
     */
    private prevPos;
    private static defaultOptions;
    constructor(options: ScrollbarOptions);
    attributeChangedCallback<Key extends keyof ScrollbarCfg>(name: Key, oldValue: ScrollbarCfg[Key], newValue: ScrollbarCfg[Key]): void;
    /**
     * 计算滑块重心在轨道的比例位置
     * @param offset 额外的偏移量
     */
    getValue(): string | number | boolean | [number, number, number, number] | number[] | import("./types").ScrollStyle | [number, number] | Float32Array | [number, number, number] | import("@antv/g").DisplayObject<any> | import("@antv/g").DisplayObject<any>[] | null | undefined;
    /**
     * 设置value
     * @param value 当前位置的占比
     */
    setValue(value: number): void;
    /**
     * 设置相对偏移，鼠标拖动、滚轮滑动时使用
     * @param offset 鼠标、滚轮的偏移量
     */
    setOffset(deltaOffset: number): void;
    init(): void;
    /**
     * 组件的更新
     */
    update(cfg: Partial<ScrollbarCfg>): void;
    /**
     * 组件的清除
     */
    clear(): void;
    private initShape;
    /**
     * 值改变事件
     */
    private onValueChanged;
    /**
     * value - offset 相互转换
     * @param num
     * @param reverse true - value -> offset; false - offset -> value
     * @returns
     */
    private valueOffset;
    private getStyle;
    /**
     * 获得轨道可用空间
     */
    private getAvailableSpace;
    /**
     * 获得轨道长度
     */
    private getTrackLen;
    /**
     * 将滑块移动至指定位置
     * @param thumbOffset 滑块位置偏移量
     */
    private setThumbOffset;
    private getTrackShapeCfg;
    private getThumbShapeCfg;
    private bindEvents;
    /**
     * 根据orient取出对应轴向上的值
     * 主要用于取鼠标坐标在orient方向上的位置
     */
    private getOrientVal;
    /**
     * 点击轨道事件
     */
    private onTrackClick;
    /**
     * 悬浮事件
     */
    private onHover;
    private onDragStart;
    private onDragging;
    private onDragEnd;
}
