import { GUI } from '../core/gui';
import type { ShapeAttrs, RectProps } from '../../types';
import type { SliderCfg, SliderOptions, HandleCfg, Pair } from './types';
export type { SliderCfg, SliderOptions };
export declare class Slider extends GUI<SliderCfg> {
    static tag: string;
    private static defaultOptions;
    /**
     * 层级关系
     * backgroundShape
     *  |- sparklineShape
     *  |- selectionShape
     *       |- startHandle
     *           |- handleIcon
     *           |- handleText
     *       |- endHandle
     *           |- handleIcon
     *           |- handleText
     */
    private backgroundShape;
    private sparklineShape;
    private foregroundGroup;
    private selectionShape;
    private startHandle;
    private endHandle;
    /**
     * 选区开始的位置
     */
    private selectionStartPos;
    /**
     * 选区宽度
     */
    private selectionWidth;
    /**
     * 记录上一次鼠标事件所在坐标
     */
    private prevPos;
    /**
     * drag事件当前选中的对象
     */
    private target;
    constructor(options: SliderOptions);
    attributeChangedCallback<Key extends keyof SliderCfg>(name: Key, oldValue: SliderCfg[Key], newValue: SliderCfg[Key]): void;
    getValues(): Pair<number>;
    setValues(values: SliderCfg['values']): void;
    getNames(): number | "vertical" | "horizontal" | Pair<number> | Pair<string> | number[] | import("../../types").MixAttrs<ShapeAttrs> | import("../../types").MixAttrs<RectProps> | HandleCfg | {
        start: HandleCfg;
        end: HandleCfg;
    } | ({
        padding?: number[] | undefined;
    } & ShapeAttrs & {
        data?: number[] | number[][] | undefined;
        width?: number | undefined;
        height?: number | undefined;
        isStack?: boolean | undefined;
        color?: string | string[] | ((idx: number) => string) | undefined;
        type?: "line" | "column" | undefined;
        smooth?: boolean | undefined;
        lineStyle?: ShapeAttrs | ((idx: number) => ShapeAttrs) | undefined;
        areaStyle?: ShapeAttrs | ((idx: number) => ShapeAttrs) | undefined;
        isGroup?: boolean | undefined;
        columnStyle?: ShapeAttrs | ((idx: number) => ShapeAttrs) | undefined;
        barPadding?: number | undefined;
    }) | undefined;
    setNames(names: SliderCfg['names']): void;
    init(): void;
    initShape(): void;
    /**
     * 组件的更新
     */
    update(cfg: Partial<SliderCfg>): void;
    /**
     * 组件的清除
     */
    clear(): void;
    /**
     * 获得安全的Values
     */
    private getSafetyValues;
    private getAvailableSpace;
    /**
     * 获取style
     * @param name style名
     * @param isActive 是否是active style
     * @returns ShapeCfg
     */
    private getStyle;
    private getBackgroundShapeCfg;
    private getSparklineShapeCfg;
    /**
     * 计算蒙板坐标和宽高
     * 默认用来计算前景位置大小
     */
    private calcMask;
    private getSelectionShapeCfg;
    /**
     * 计算手柄的x y
     */
    private calcHandlePosition;
    /**
     * 设置选区
     * 1. 设置前景大小及位置
     * 2. 设置手柄位置
     * 3. 更新文本位置
     */
    private setHandle;
    /**
     * 计算手柄应当处于的位置
     * @param name 手柄文字
     * @param handleType start手柄还是end手柄
     * @returns
     */
    private calcHandleText;
    private getHandleTextShapeCfg;
    private getHandleIconShapeCfg;
    private getHandleShapeCfg;
    /**
     * 创建手柄
     */
    private createHandle;
    private getHandleCfg;
    private getHandleSize;
    private bindEvents;
    private getOrientVal;
    private setValuesOffset;
    private getRatio;
    private onDragStart;
    private onDragging;
    private onDragEnd;
}
